Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(189)

Unified Diff: components/test_runner/web_test_interfaces.h

Issue 2238573002: Add WebWidgetTestProxy. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: add missing files Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/test_runner/test_runner.gyp ('k') | components/test_runner/web_test_interfaces.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/test_runner/web_test_interfaces.h
diff --git a/components/test_runner/web_test_interfaces.h b/components/test_runner/web_test_interfaces.h
index 2a73e7b7e85816d1ee791cf3b553ac20c6fac41e..6bf9ef1b7f69db68e63e1e3a85799aba274e30cf 100644
--- a/components/test_runner/web_test_interfaces.h
+++ b/components/test_runner/web_test_interfaces.h
@@ -35,6 +35,7 @@ class WebFrameTestClient;
class WebFrameTestProxyBase;
class WebTestDelegate;
class WebViewTestProxyBase;
+class WebWidgetTestProxyBase;
class WebTestRunner;
class WebViewTestClient;
class WebWidgetTestClient;
@@ -86,9 +87,9 @@ class TEST_RUNNER_EXPORT WebTestInterfaces {
// Creates a WebWidgetClient implementation providing test behavior (i.e.
// providing a mocked screen orientation). The caller should guarantee that
// the returned pointer won't be used beyond the lifetime of WebTestInterfaces
// and/or the lifetime of |web_view_test_proxy_base|.
std::unique_ptr<WebWidgetTestClient> CreateWebWidgetTestClient(
- WebViewTestProxyBase* web_view_test_proxy_base);
+ WebWidgetTestProxyBase* web_widget_test_proxy_base);
// Gets a list of currently opened windows created by the current test.
std::vector<blink::WebView*> GetWindowList();
« no previous file with comments | « components/test_runner/test_runner.gyp ('k') | components/test_runner/web_test_interfaces.cc » ('j') | no next file with comments »
@@ -86,9 +87,9 @@ class TEST_RUNNER_EXPORT WebTestInterfaces {
// providing a mocked screen orientation). The caller should guarantee that
// the returned pointer won't be used beyond the lifetime of WebTestInterfaces
- // and/or the lifetime of |web_view_test_proxy_base|.
+ // and/or the lifetime of |web_widget_test_proxy_base|.
std::unique_ptr<WebWidgetTestClient> CreateWebWidgetTestClient(

Powered by Google App Engine
This is Rietveld 408576698